@@ -36,13 +36,38 @@ from casadi import (
     pi,
     fabs,
     linspace,
+    erf,
+    erfinv,
+    norm_1,
+    sign,
+    fmin,
+    fmax,
+    mmin,
+    mmax,
+    find,
     #
     if_else,
+    logic_and,
+    logic_or,
+    logic_not,
+    floor,
+    ceil,
+    
     SX,
     DM,
     MX,
+    #
+    vertcat,
+    horzcat,
+    vertsplit,
+    horzsplit,
+    reshape,
 )
 
+eye = SX.eye
+ones = SX.ones
+zeros = SX.zeros
+
 
 def invariants(T):
 
@@ -66,3 +91,8 @@ def eigvals(T, eps=1e-5):
 def cof(T):
 
     return det(T) * transpose(inv(T))
+
+
+def sym(T):
+
+    return (T + transpose(T)) / 2
